"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DiskSpec(google.protobuf.message.Message):
    """Disk specificaton."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DiskSpec._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: DiskSpec._Type.ValueType  # 0
        """Disk type is not specified."""
        HDD: DiskSpec._Type.ValueType  # 1
        """HDD disk type."""
        SSD: DiskSpec._Type.ValueType  # 2
        """SSD disk type."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: DiskSpec.Type.ValueType  # 0
    """Disk type is not specified."""
    HDD: DiskSpec.Type.ValueType  # 1
    """HDD disk type."""
    SSD: DiskSpec.Type.ValueType  # 2
    """SSD disk type."""

    TYPE_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    type: global___DiskSpec.Type.ValueType
    """Type of disk."""
    size: builtins.int
    """Size of disk."""
    def __init__(
        self,
        *,
        type: global___DiskSpec.Type.ValueType = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["size", b"size", "type", b"type"]) -> None: ...

global___DiskSpec = DiskSpec



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import group_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2
from yandex.cloud.organizationmanager.v1 import group_service_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/organizationmanager/v1/group_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class GroupServiceStub(object):
    """A set of methods for managing groups.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/Get',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.GetGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2.Group.FromString,
                _registered_method=True)
        self.ResolveExternal = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/ResolveExternal',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ResolveExternalGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2.Group.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/List',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupsResponse.FromString,
                _registered_method=True)
        self.ListExternal = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/ListExternal',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListExternalGroupsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListExternalGroupsResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/Create',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.CreateGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.CreateExternal = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/CreateExternal',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.CreateExternalGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/Update',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.UpdateGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ConvertToExternal = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/ConvertToExternal',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ConvertToExternalGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ConvertAllToBasic = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/ConvertAllToBasic',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ConvertAllToBasicGroupsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/Delete',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.DeleteGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupOperationsResponse.FromString,
                _registered_method=True)
        self.ListMembers = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/ListMembers',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupMembersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupMembersResponse.FromString,
                _registered_method=True)
        self.UpdateMembers = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/UpdateMembers',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.UpdateGroupMembersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                _registered_method=True)
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.GroupService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class GroupServiceServicer(object):
    """A set of methods for managing groups.
    """

    def Get(self, request, context):
        """Returns the specified Group resource.

        To get the list of available Group resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResolveExternal(self, request, context):
        """Returns external group by subject container and external id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of group resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExternal(self, request, context):
        """Retrieves the list of external group linked subject container
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a group in the specified organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateExternal(self, request, context):
        """Creates an external group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConvertToExternal(self, request, context):
        """Converts single basic (not external) group to external. Precondition: group must be basic. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConvertAllToBasic(self, request, context):
        """Converts all groups that belongs to subject container from external to basic (not external).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMembers(self, request, context):
        """members

        List group active members.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMembers(self, request, context):
        """Update group members.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """access

        Lists access bindings for the specified group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the specified group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GroupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.GetGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2.Group.SerializeToString,
            ),
            'ResolveExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.ResolveExternal,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ResolveExternalGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2.Group.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupsResponse.SerializeToString,
            ),
            'ListExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExternal,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListExternalGroupsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListExternalGroupsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.CreateGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'CreateExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateExternal,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.CreateExternalGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.UpdateGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ConvertToExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.ConvertToExternal,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ConvertToExternalGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ConvertAllToBasic': grpc.unary_unary_rpc_method_handler(
                    servicer.ConvertAllToBasic,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ConvertAllToBasicGroupsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.DeleteGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupOperationsResponse.SerializeToString,
            ),
            'ListMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMembers,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupMembersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupMembersResponse.SerializeToString,
            ),
            'UpdateMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMembers,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.UpdateGroupMembersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.organizationmanager.v1.GroupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.organizationmanager.v1.GroupService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class GroupService(object):
    """A set of methods for managing groups.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/Get',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.GetGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2.Group.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ResolveExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/ResolveExternal',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ResolveExternalGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2.Group.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/List',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/ListExternal',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListExternalGroupsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListExternalGroupsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/Create',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.CreateGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/CreateExternal',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.CreateExternalGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/Update',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.UpdateGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConvertToExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/ConvertToExternal',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ConvertToExternalGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConvertAllToBasic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/ConvertAllToBasic',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ConvertAllToBasicGroupsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/Delete',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.DeleteGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/ListOperations',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/ListMembers',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupMembersRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.ListGroupMembersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/UpdateMembers',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__service__pb2.UpdateGroupMembersRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.GroupService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/opensearch/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/opensearch/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.operationlog.v1 import operation_log_pb2 as yandex_dot_cloud_dot_mdb_dot_operationlog_dot_v1_dot_operation__log__pb2
from yandex.cloud.mdb.opensearch.v1 import auth_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_auth__pb2
from yandex.cloud.mdb.opensearch.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.opensearch.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.opensearch.v1.config import opensearch_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_config_dot_opensearch__pb2
from yandex.cloud.mdb.opensearch.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_maintenance__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/opensearch/v1/cluster_service.proto\x12\x1eyandex.cloud.mdb.opensearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a\x34yandex/cloud/mdb/operationlog/v1/operation_log.proto\x1a)yandex/cloud/mdb/opensearch/v1/auth.proto\x1a+yandex/cloud/mdb/opensearch/v1/backup.proto\x1a,yandex/cloud/mdb/opensearch/v1/cluster.proto\x1a\x36yandex/cloud/mdb/opensearch/v1/config/opensearch.proto\x1a\x30yandex/cloud/mdb/opensearch/v1/maintenance.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"j\n\x14ListClustersResponse\x12\x39\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.opensearch.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdf\x05\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.opensearch.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12H\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.mdb.opensearch.v1.Cluster.Environment\x12K\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.mdb.opensearch.v1.ConfigCreateSpecB\x04\xe8\xc7\x31\x01\x12 \n\nnetwork_id\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12M\n\x12maintenance_window\x18\x0b \x01(\x0b\x32\x31.yandex.cloud.mdb.opensearch.v1.MaintenanceWindow\x12<\n\x16\x64isk_encryption_key_id\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x45\n\roperation_log\x18\x02 \x01(\x0b\x32..yandex.cloud.mdb.operationlog.v1.OperationLog\"\xfb\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x45\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.mdb.opensearch.v1.ConfigUpdateSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12M\n\x12maintenance_window\x18\n \x01(\x0b\x32\x31.yandex.cloud.mdb.opensearch.v1.MaintenanceWindow\x12\x1c\n\nnetwork_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=50\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x45\n\roperation_log\x18\x02 \x01(\x0b\x32..yandex.cloud.mdb.operationlog.v1.OperationLog\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xce\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12-\n\tfrom_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x05 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x07 \x01(\x08\x12\x1a\n\x06\x66ilter\x18\x08 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12X\n\x0cservice_type\x18\t \x01(\x0e\x32\x42.yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest.ServiceType\"K\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nOPENSEARCH\x10\x01\x12\x0e\n\nDASHBOARDS\x10\x02\"\xb3\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x07message\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.mdb.opensearch.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x17ListClusterLogsResponse\x12\x37\n\x04logs\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.opensearch.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x0fStreamLogRecord\x12\x39\n\x06record\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\x95\x03\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12-\n\tfrom_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x06 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12Z\n\x0cservice_type\x18\x07 \x01(\x0e\x32\x44.yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest.ServiceType\"K\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nOPENSEARCH\x10\x01\x12\x0e\n\nDASHBOARDS\x10\x02\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"h\n\x18ListClusterHostsResponse\x12\x33\n\x05hosts\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.opensearch.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xe8\x02\n\x10\x43onfigCreateSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1c\n\x0e\x61\x64min_password\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12M\n\x0fopensearch_spec\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec\x12M\n\x0f\x64\x61shboards_spec\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x05 \x01(\x0b\x32&.yandex.cloud.mdb.opensearch.v1.Access\x12O\n\x13snapshot_management\x18\x06 \x01(\x0b\x32\x32.yandex.cloud.mdb.opensearch.v1.SnapshotManagement\".\n\x0fKeystoreSetting\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xd4\x05\n\x14OpenSearchCreateSpec\x12\x0f\n\x07plugins\x18\x01 \x03(\t\x12S\n\x0bnode_groups\x18\x02 \x03(\x0b\x32>.yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup\x12k\n\x13opensearch_config_2\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.mdb.opensearch.v1.config.OpenSearchConfig2H\x00R\x12opensearchConfig_2\x12J\n\x11keystore_settings\x18\x04 \x03(\x0b\x32/.yandex.cloud.mdb.opensearch.v1.KeystoreSetting\x1a\x92\x03\n\tNodeGroup\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12<\n\tresources\x18\x02 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.Resources\x12\x1c\n\x0bhosts_count\x18\x03 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\"\n\x08zone_ids\x18\x04 \x03(\tB\x10\x82\xc8\x31\x04<=10\x8a\xc8\x31\x04<=50\x12$\n\nsubnet_ids\x18\x05 \x03(\tB\x10\x82\xc8\x31\x04<=10\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x06 \x01(\x08\x12\x43\n\x05roles\x18\x07 \x03(\x0e\x32\x34.yandex.cloud.mdb.opensearch.v1.OpenSearch.GroupRole\x12R\n\x15\x64isk_size_autoscaling\x18\x08 \x01(\x0b\x32\x33.yandex.cloud.mdb.opensearch.v1.DiskSizeAutoscalingB\x08\n\x06\x63onfig\"\xa9\x03\n\x14\x44\x61shboardsCreateSpec\x12S\n\x0bnode_groups\x18\x02 \x03(\x0b\x32>.yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup\x1a\xbb\x02\n\tNodeGroup\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12<\n\tresources\x18\x02 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.Resources\x12\x1c\n\x0bhosts_count\x18\x03 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x10\n\x08zone_ids\x18\x04 \x03(\t\x12$\n\nsubnet_ids\x18\x05 \x03(\tB\x10\x82\xc8\x31\x04<=10\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x06 \x01(\x08\x12R\n\x15\x64isk_size_autoscaling\x18\x07 \x01(\x0b\x32\x33.yandex.cloud.mdb.opensearch.v1.DiskSizeAutoscaling\"\xf6\x02\n\x10\x43onfigUpdateSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1c\n\x0e\x61\x64min_password\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12T\n\x0fopensearch_spec\x18\x03 \x01(\x0b\x32;.yandex.cloud.mdb.opensearch.v1.OpenSearchClusterUpdateSpec\x12T\n\x0f\x64\x61shboards_spec\x18\x04 \x01(\x0b\x32;.yandex.cloud.mdb.opensearch.v1.DashboardsClusterUpdateSpec\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x05 \x01(\x0b\x32&.yandex.cloud.mdb.opensearch.v1.Access\x12O\n\x13snapshot_management\x18\x06 \x01(\x0b\x32\x32.yandex.cloud.mdb.opensearch.v1.SnapshotManagement\"\x97\x02\n\x1bOpenSearchClusterUpdateSpec\x12\x0f\n\x07plugins\x18\x01 \x03(\t\x12k\n\x13opensearch_config_2\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.opensearch.v1.config.OpenSearchConfig2H\x00R\x12opensearchConfig_2\x12N\n\x15set_keystore_settings\x18\x03 \x03(\x0b\x32/.yandex.cloud.mdb.opensearch.v1.KeystoreSetting\x12 \n\x18remove_keystore_settings\x18\x04 \x03(\tB\x08\n\x06\x63onfig\"\x1d\n\x1b\x44\x61shboardsClusterUpdateSpec\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"X\n\x13\x44\x65leteBackupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\tbackup_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"=\n\x14\x44\x65leteBackupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xfa\x05\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x41.yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12H\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.mdb.opensearch.v1.Cluster.Environment\x12K\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.mdb.opensearch.v1.ConfigCreateSpecB\x04\xe8\xc7\x31\x01\x12 \n\nnetwork_id\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12\x1f\n\tfolder_id\x18\x0b \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12M\n\x12maintenance_window\x18\x0c \x01(\x0b\x32\x31.yandex.cloud.mdb.opensearch.v1.MaintenanceWindow\x12<\n\x16\x64isk_encryption_key_id\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xcf\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12j\n\x0freschedule_type\x18\x02 \x01(\x0e\x32K.yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"l\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x04\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1aListClusterBackupsResponse\x12\x37\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.opensearch.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"R\n DeleteOpenSearchNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xfb\x01\n UpdateOpenSearchNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12V\n\x0fnode_group_spec\x18\x04 \x01(\x0b\x32=.yandex.cloud.mdb.opensearch.v1.OpenSearchNodeGroupUpdateSpec\"\xcb\x02\n\x1dOpenSearchNodeGroupUpdateSpec\x12<\n\tresources\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.Resources\x12\x13\n\x0bhosts_count\x18\x02 \x01(\x03\x12\x43\n\x05roles\x18\x03 \x03(\x0e\x32\x34.yandex.cloud.mdb.opensearch.v1.OpenSearch.GroupRole\x12\x10\n\x08zone_ids\x18\x04 \x03(\t\x12\x12\n\nsubnet_ids\x18\x05 \x03(\t\x12\x18\n\x10\x61ssign_public_ip\x18\x06 \x01(\x08\x12R\n\x15\x64isk_size_autoscaling\x18\x07 \x01(\x0b\x32\x33.yandex.cloud.mdb.opensearch.v1.DiskSizeAutoscaling\"\x9a\x01\n\x1d\x41\x64\x64OpenSearchNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x0fnode_group_spec\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.opensearch.v1.OpenSearchCreateSpec.NodeGroup\"r\n DeleteDashboardsNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"\xfb\x01\n UpdateDashboardsNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12V\n\x0fnode_group_spec\x18\x04 \x01(\x0b\x32=.yandex.cloud.mdb.opensearch.v1.DashboardsNodeGroupUpdateSpec\"\x86\x02\n\x1d\x44\x61shboardsNodeGroupUpdateSpec\x12<\n\tresources\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.opensearch.v1.Resources\x12\x13\n\x0bhosts_count\x18\x02 \x01(\x03\x12\x10\n\x08zone_ids\x18\x03 \x03(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12\x18\n\x10\x61ssign_public_ip\x18\x05 \x01(\x08\x12R\n\x15\x64isk_size_autoscaling\x18\x06 \x01(\x0b\x32\x33.yandex.cloud.mdb.opensearch.v1.DiskSizeAutoscaling\"\x9a\x01\n\x1d\x41\x64\x64\x44\x61shboardsNodeGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x0fnode_group_spec\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.opensearch.v1.DashboardsCreateSpec.NodeGroup\"8\n\x14\x41\x64\x64NodeGroupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\";\n\x17UpdateNodeGroupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\";\n\x17\x44\x65leteNodeGroupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x16GetAuthSettingsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"}\n\x19UpdateAuthSettingsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08settings\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.opensearch.v1.AuthSettings\"0\n\x1aUpdateAuthSettingsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"P\n\x18RestartOpenSearchRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\x04host\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"=\n\x19RestartOpenSearchMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\"K\n\x13SwitchMasterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\nfrom_hosts\x18\x02 \x03(\t\">\n\x14SwitchMasterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nfrom_hosts\x18\x02 \x03(\t2\x82-\n\x0e\x43lusterService\x12\x97\x01\n\x03Get\x12\x31.yandex.cloud.mdb.opensearch.v1.GetClusterRequest\x1a\'.yandex.cloud.mdb.opensearch.v1.Cluster\"4\x82\xd3\xe4\x93\x02.\x12,/managed-opensearch/v1/clusters/{cluster_id}\x12\x9a\x01\n\x04List\x12\x33.yandex.cloud.mdb.opensearch.v1.ListClustersRequest\x1a\x34.yandex.cloud.mdb.opensearch.v1.ListClustersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/managed-opensearch/v1/clusters\x12\xb1\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.opensearch.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02$\"\x1f/managed-opensearch/v1/clusters:\x01*\x12\xbe\x01\n\x06Update\x12\x34.yandex.cloud.mdb.opensearch.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\x32,/managed-opensearch/v1/clusters/{cluster_id}:\x01*\x12\xc9\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.opensearch.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.*,/managed-opensearch/v1/clusters/{cluster_id}\x12\xc2\x01\n\x06\x42\x61\x63kup\x12\x34.yandex.cloud.mdb.opensearch.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x35\"3/managed-opensearch/v1/clusters/{cluster_id}:backup\x12\xe1\x01\n\x0c\x44\x65leteBackup\x12\x33.yandex.cloud.mdb.opensearch.v1.DeleteBackupRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*-\n\x14\x44\x65leteBackupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42*@/managed-opensearch/v1/clusters/{cluster_id}/backups/{backup_id}\x12\xbc\x01\n\x07Restore\x12\x35.yandex.cloud.mdb.opensearch.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,\"\'/managed-opensearch/v1/clusters:restore:\x01*\x12\xf3\x01\n\x15RescheduleMaintenance\x12<.yandex.cloud.mdb.opensearch.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02G\"B/managed-opensearch/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\x12\xc2\x01\n\x0bListBackups\x12\x39.yandex.cloud.mdb.opensearch.v1.ListClusterBackupsRequest\x1a:.yandex.cloud.mdb.opensearch.v1.ListClusterBackupsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-opensearch/v1/clusters/{cluster_id}/backups\x12\xbd\x01\n\x04Move\x12\x32.yandex.cloud.mdb.opensearch.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x36\"1/managed-opensearch/v1/clusters/{cluster_id}:move:\x01*\x12\xbe\x01\n\x05Start\x12\x33.yandex.cloud.mdb.opensearch.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x34\"2/managed-opensearch/v1/clusters/{cluster_id}:start\x12\xba\x01\n\x04Stop\x12\x32.yandex.cloud.mdb.opensearch.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x33\"1/managed-opensearch/v1/clusters/{cluster_id}:stop\x12\xb6\x01\n\x08ListLogs\x12\x36.yandex.cloud.mdb.opensearch.v1.ListClusterLogsRequest\x1a\x37.yandex.cloud.mdb.opensearch.v1.ListClusterLogsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-opensearch/v1/clusters/{cluster_id}:logs\x12\xbb\x01\n\nStreamLogs\x12\x38.yandex.cloud.mdb.opensearch.v1.StreamClusterLogsRequest\x1a/.yandex.cloud.mdb.opensearch.v1.StreamLogRecord\"@\x82\xd3\xe4\x93\x02:\x12\x38/managed-opensearch/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xce\x01\n\x0eListOperations\x12<.yandex.cloud.mdb.opensearch.v1.ListClusterOperationsRequest\x1a=.yandex.cloud.mdb.opensearch.v1.ListClusterOperationsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-opensearch/v1/clusters/{cluster_id}/operations\x12\xba\x01\n\tListHosts\x12\x37.yandex.cloud.mdb.opensearch.v1.ListClusterHostsRequest\x1a\x38.yandex.cloud.mdb.opensearch.v1.ListClusterHostsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-opensearch/v1/clusters/{cluster_id}/hosts\x12\xfb\x01\n\x16\x41\x64\x64OpenSearchNodeGroup\x12=.yandex.cloud.mdb.opensearch.v1.AddOpenSearchNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*-\n\x14\x41\x64\x64NodeGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02H\"C/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups:\x01*\x12\x89\x02\n\x19\x44\x65leteOpenSearchNodeGroup\x12@.yandex.cloud.mdb.opensearch.v1.DeleteOpenSearchNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02L*J/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups/{name}\x12\x8c\x02\n\x19UpdateOpenSearchNodeGroup\x12@.yandex.cloud.mdb.opensearch.v1.UpdateOpenSearchNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*0\n\x17UpdateNodeGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02O2J/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups/{name}:\x01*\x12\xfb\x01\n\x16\x41\x64\x64\x44\x61shboardsNodeGroup\x12=.yandex.cloud.mdb.opensearch.v1.AddDashboardsNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*-\n\x14\x41\x64\x64NodeGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02H\"C/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups:\x01*\x12\x89\x02\n\x19\x44\x65leteDashboardsNodeGroup\x12@.yandex.cloud.mdb.opensearch.v1.DeleteDashboardsNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02L*J/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups/{name}\x12\x8c\x02\n\x19UpdateDashboardsNodeGroup\x12@.yandex.cloud.mdb.opensearch.v1.UpdateDashboardsNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*0\n\x17UpdateNodeGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02O2J/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups/{name}:\x01*\x12\xb2\x01\n\x0fGetAuthSettings\x12\x36.yandex.cloud.mdb.opensearch.v1.GetAuthSettingsRequest\x1a,.yandex.cloud.mdb.opensearch.v1.AuthSettings\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-opensearch/v1/clusters/{cluster_id}/auth\x12\xde\x01\n\x12UpdateAuthSettings\x12\x39.yandex.cloud.mdb.opensearch.v1.UpdateAuthSettingsRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2**\n\x1aUpdateAuthSettingsMetadata\x12\x0c\x41uthSettings\x82\xd3\xe4\x93\x02\x36\x1a\x31/managed-opensearch/v1/clusters/{cluster_id}/auth:\x01*\x12\xe8\x01\n\x11RestartOpenSearch\x12\x38.yandex.cloud.mdb.opensearch.v1.RestartOpenSearchRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*2\n\x19RestartOpenSearchMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02:\"8/managed-opensearch/v1/clusters/{cluster_id}/host/{host}\x12\xde\x01\n\x0cSwitchMaster\x12\x33.yandex.cloud.mdb.opensearch.v1.SwitchMasterRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*-\n\x14SwitchMasterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?\":/managed-opensearch/v1/clusters/{cluster_id}:switch_master:\x01*Bs\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.opensearch.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearch'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LOGRECORD_MESSAGEENTRY']._loaded_options = None
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CONFIGCREATESPEC'].fields_by_name['admin_password']._loaded_options = None
  _globals['_CONFIGCREATESPEC'].fields_by_name['admin_password']._serialized_options = b'\350\3071\001'
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP'].fields_by_name['name']._loaded_options = None
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP'].fields_by_name['hosts_count']._loaded_options = None
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP'].fields_by_name['hosts_count']._serialized_options = b'\372\3071\003>=1'
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP'].fields_by_name['zone_ids']._loaded_options = None
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP'].fields_by_name['zone_ids']._serialized_options = b'\202\3101\004<=10\212\3101\004<=50'
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP'].fields_by_name['subnet_ids']._loaded_options = None
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP'].fields_by_name['subnet_ids']._serialized_options = b'\202\3101\004<=10\212\3101\004<=50'
  _globals['_DASHBOARDSCREATESPEC_NODEGROUP'].fields_by_name['name']._loaded_options = None
  _globals['_DASHBOARDSCREATESPEC_NODEGROUP'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DASHBOARDSCREATESPEC_NODEGROUP'].fields_by_name['hosts_count']._loaded_options = None
  _globals['_DASHBOARDSCREATESPEC_NODEGROUP'].fields_by_name['hosts_count']._serialized_options = b'\372\3071\003>=1'
  _globals['_DASHBOARDSCREATESPEC_NODEGROUP'].fields_by_name['subnet_ids']._loaded_options = None
  _globals['_DASHBOARDSCREATESPEC_NODEGROUP'].fields_by_name['subnet_ids']._serialized_options = b'\202\3101\004<=10\212\3101\004<=50'
  _globals['_CONFIGUPDATESPEC'].fields_by_name['admin_password']._loaded_options = None
  _globals['_CONFIGUPDATESPEC'].fields_by_name['admin_password']._serialized_options = b'\350\3071\001'
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBACKUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEBACKUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBACKUPREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_DELETEBACKUPREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._serialized_options = b'\350\3071\001'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_DELETEOPENSEARCHNODEGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEOPENSEARCHNODEGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEOPENSEARCHNODEGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEOPENSEARCHNODEGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEOPENSEARCHNODEGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEOPENSEARCHNODEGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_ADDOPENSEARCHNODEGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDOPENSEARCHNODEGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDASHBOARDSNODEGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEDASHBOARDSNODEGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDASHBOARDSNODEGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEDASHBOARDSNODEGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATEDASHBOARDSNODEGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEDASHBOARDSNODEGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEDASHBOARDSNODEGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEDASHBOARDSNODEGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_ADDDASHBOARDSNODEGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDDASHBOARDSNODEGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETAUTHSETTINGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETAUTHSETTINGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEAUTHSETTINGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEAUTHSETTINGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTARTOPENSEARCHREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESTARTOPENSEARCHREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTARTOPENSEARCHREQUEST'].fields_by_name['host']._loaded_options = None
  _globals['_RESTARTOPENSEARCHREQUEST'].fields_by_name['host']._serialized_options = b'\350\3071\001'
  _globals['_SWITCHMASTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_SWITCHMASTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002.\022,/managed-opensearch/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/managed-opensearch/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002$\"\037/managed-opensearch/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\00212,/managed-opensearch/v1/clusters/{cluster_id}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002.*,/managed-opensearch/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0025\"3/managed-opensearch/v1/clusters/{cluster_id}:backup'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteBackup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteBackup']._serialized_options = b'\262\322*-\n\024DeleteBackupMetadata\022\025google.protobuf.Empty\202\323\344\223\002B*@/managed-opensearch/v1/clusters/{cluster_id}/backups/{backup_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002,\"\'/managed-opensearch/v1/clusters:restore:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._serialized_options = b'\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster\202\323\344\223\002G\"B/managed-opensearch/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0026\0224/managed-opensearch/v1/clusters/{cluster_id}/backups'
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0026\"1/managed-opensearch/v1/clusters/{cluster_id}:move:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0024\"2/managed-opensearch/v1/clusters/{cluster_id}:start'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0023\"1/managed-opensearch/v1/clusters/{cluster_id}:stop'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\0023\0221/managed-opensearch/v1/clusters/{cluster_id}:logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._serialized_options = b'\202\323\344\223\002:\0228/managed-opensearch/v1/clusters/{cluster_id}:stream_logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0029\0227/managed-opensearch/v1/clusters/{cluster_id}/operations'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\0024\0222/managed-opensearch/v1/clusters/{cluster_id}/hosts'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddOpenSearchNodeGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddOpenSearchNodeGroup']._serialized_options = b'\262\322*-\n\024AddNodeGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002H\"C/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteOpenSearchNodeGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteOpenSearchNodeGroup']._serialized_options = b'\262\322*0\n\027DeleteNodeGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002L*J/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups/{name}'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateOpenSearchNodeGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateOpenSearchNodeGroup']._serialized_options = b'\262\322*0\n\027UpdateNodeGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002O2J/managed-opensearch/v1/clusters/{cluster_id}/opensearch/node_groups/{name}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddDashboardsNodeGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddDashboardsNodeGroup']._serialized_options = b'\262\322*-\n\024AddNodeGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002H\"C/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteDashboardsNodeGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteDashboardsNodeGroup']._serialized_options = b'\262\322*0\n\027DeleteNodeGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002L*J/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups/{name}'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateDashboardsNodeGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateDashboardsNodeGroup']._serialized_options = b'\262\322*0\n\027UpdateNodeGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002O2J/managed-opensearch/v1/clusters/{cluster_id}/dashboards/node_groups/{name}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['GetAuthSettings']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['GetAuthSettings']._serialized_options = b'\202\323\344\223\0023\0221/managed-opensearch/v1/clusters/{cluster_id}/auth'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateAuthSettings']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateAuthSettings']._serialized_options = b'\262\322**\n\032UpdateAuthSettingsMetadata\022\014AuthSettings\202\323\344\223\0026\0321/managed-opensearch/v1/clusters/{cluster_id}/auth:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['RestartOpenSearch']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['RestartOpenSearch']._serialized_options = b'\262\322*2\n\031RestartOpenSearchMetadata\022\025google.protobuf.Empty\202\323\344\223\002:\"8/managed-opensearch/v1/clusters/{cluster_id}/host/{host}'
  _globals['_CLUSTERSERVICE'].methods_by_name['SwitchMaster']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['SwitchMaster']._serialized_options = b'\262\322*-\n\024SwitchMasterMetadata\022\025google.protobuf.Empty\202\323\344\223\002?\":/managed-opensearch/v1/clusters/{cluster_id}:switch_master:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=616
  _globals['_GETCLUSTERREQUEST']._serialized_end=669
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=672
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=816
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=818
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=924
  _globals['_CREATECLUSTERREQUEST']._serialized_start=927
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1662
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1617
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1662
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1664
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1778
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1781
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2416
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1617
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1662
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2418
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2532
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2534
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2590
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2592
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2635
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=2638
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=3100
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=3025
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=3100
  _globals['_LOGRECORD']._serialized_start=3103
  _globals['_LOGRECORD']._serialized_end=3282
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=3236
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=3282
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=3284
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=3391
  _globals['_STREAMLOGRECORD']._serialized_start=3393
  _globals['_STREAMLOGRECORD']._serialized_end=3496
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_start=3499
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_end=3904
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=3025
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=3100
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=3906
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=4032
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=4034
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=4145
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=4147
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=4268
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=4270
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=4374
  _globals['_MOVECLUSTERREQUEST']._serialized_start=4376
  _globals['_MOVECLUSTERREQUEST']._serialized_end=4475
  _globals['_MOVECLUSTERMETADATA']._serialized_start=4477
  _globals['_MOVECLUSTERMETADATA']._serialized_end=4575
  _globals['_STARTCLUSTERREQUEST']._serialized_start=4577
  _globals['_STARTCLUSTERREQUEST']._serialized_end=4632
  _globals['_STARTCLUSTERMETADATA']._serialized_start=4634
  _globals['_STARTCLUSTERMETADATA']._serialized_end=4676
  _globals['_STOPCLUSTERREQUEST']._serialized_start=4678
  _globals['_STOPCLUSTERREQUEST']._serialized_end=4732
  _globals['_STOPCLUSTERMETADATA']._serialized_start=4734
  _globals['_STOPCLUSTERMETADATA']._serialized_end=4775
  _globals['_CONFIGCREATESPEC']._serialized_start=4778
  _globals['_CONFIGCREATESPEC']._serialized_end=5138
  _globals['_KEYSTORESETTING']._serialized_start=5140
  _globals['_KEYSTORESETTING']._serialized_end=5186
  _globals['_OPENSEARCHCREATESPEC']._serialized_start=5189
  _globals['_OPENSEARCHCREATESPEC']._serialized_end=5913
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP']._serialized_start=5501
  _globals['_OPENSEARCHCREATESPEC_NODEGROUP']._serialized_end=5903
  _globals['_DASHBOARDSCREATESPEC']._serialized_start=5916
  _globals['_DASHBOARDSCREATESPEC']._serialized_end=6341
  _globals['_DASHBOARDSCREATESPEC_NODEGROUP']._serialized_start=6026
  _globals['_DASHBOARDSCREATESPEC_NODEGROUP']._serialized_end=6341
  _globals['_CONFIGUPDATESPEC']._serialized_start=6344
  _globals['_CONFIGUPDATESPEC']._serialized_end=6718
  _globals['_OPENSEARCHCLUSTERUPDATESPEC']._serialized_start=6721
  _globals['_OPENSEARCHCLUSTERUPDATESPEC']._serialized_end=7000
  _globals['_DASHBOARDSCLUSTERUPDATESPEC']._serialized_start=7002
  _globals['_DASHBOARDSCLUSTERUPDATESPEC']._serialized_end=7031
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=7033
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=7089
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=7091
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=7134
  _globals['_DELETEBACKUPREQUEST']._serialized_start=7136
  _globals['_DELETEBACKUPREQUEST']._serialized_end=7224
  _globals['_DELETEBACKUPMETADATA']._serialized_start=7226
  _globals['_DELETEBACKUPMETADATA']._serialized_end=7287
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=7290
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=8052
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=1617
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=1662
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=8054
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=8117
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=8120
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=8455
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_start=8345
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_end=8455
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_start=8457
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_end=8565
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=8567
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=8690
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=8692
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=8802
  _globals['_DELETEOPENSEARCHNODEGROUPREQUEST']._serialized_start=8804
  _globals['_DELETEOPENSEARCHNODEGROUPREQUEST']._serialized_end=8886
  _globals['_UPDATEOPENSEARCHNODEGROUPREQUEST']._serialized_start=8889
  _globals['_UPDATEOPENSEARCHNODEGROUPREQUEST']._serialized_end=9140
  _globals['_OPENSEARCHNODEGROUPUPDATESPEC']._serialized_start=9143
  _globals['_OPENSEARCHNODEGROUPUPDATESPEC']._serialized_end=9474
  _globals['_ADDOPENSEARCHNODEGROUPREQUEST']._serialized_start=9477
  _globals['_ADDOPENSEARCHNODEGROUPREQUEST']._serialized_end=9631
  _globals['_DELETEDASHBOARDSNODEGROUPREQUEST']._serialized_start=9633
  _globals['_DELETEDASHBOARDSNODEGROUPREQUEST']._serialized_end=9747
  _globals['_UPDATEDASHBOARDSNODEGROUPREQUEST']._serialized_start=9750
  _globals['_UPDATEDASHBOARDSNODEGROUPREQUEST']._serialized_end=10001
  _globals['_DASHBOARDSNODEGROUPUPDATESPEC']._serialized_start=10004
  _globals['_DASHBOARDSNODEGROUPUPDATESPEC']._serialized_end=10266
  _globals['_ADDDASHBOARDSNODEGROUPREQUEST']._serialized_start=10269
  _globals['_ADDDASHBOARDSNODEGROUPREQUEST']._serialized_end=10423
  _globals['_ADDNODEGROUPMETADATA']._serialized_start=10425
  _globals['_ADDNODEGROUPMETADATA']._serialized_end=10481
  _globals['_UPDATENODEGROUPMETADATA']._serialized_start=10483
  _globals['_UPDATENODEGROUPMETADATA']._serialized_end=10542
  _globals['_DELETENODEGROUPMETADATA']._serialized_start=10544
  _globals['_DELETENODEGROUPMETADATA']._serialized_end=10603
  _globals['_GETAUTHSETTINGSREQUEST']._serialized_start=10605
  _globals['_GETAUTHSETTINGSREQUEST']._serialized_end=10663
  _globals['_UPDATEAUTHSETTINGSREQUEST']._serialized_start=10665
  _globals['_UPDATEAUTHSETTINGSREQUEST']._serialized_end=10790
  _globals['_UPDATEAUTHSETTINGSMETADATA']._serialized_start=10792
  _globals['_UPDATEAUTHSETTINGSMETADATA']._serialized_end=10840
  _globals['_RESTARTOPENSEARCHREQUEST']._serialized_start=10842
  _globals['_RESTARTOPENSEARCHREQUEST']._serialized_end=10922
  _globals['_RESTARTOPENSEARCHMETADATA']._serialized_start=10924
  _globals['_RESTARTOPENSEARCHMETADATA']._serialized_end=10985
  _globals['_SWITCHMASTERREQUEST']._serialized_start=10987
  _globals['_SWITCHMASTERREQUEST']._serialized_end=11062
  _globals['_SWITCHMASTERMETADATA']._serialized_start=11064
  _globals['_SWITCHMASTERMETADATA']._serialized_end=11126
  _globals['_CLUSTERSERVICE']._serialized_start=11129
  _globals['_CLUSTERSERVICE']._serialized_end=16891
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Broker(google.protobuf.message.Message):
    """A broker."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Broker._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Broker._Status.ValueType  # 0
        CREATING: Broker._Status.ValueType  # 1
        """Broker is being created."""
        ACTIVE: Broker._Status.ValueType  # 2
        """Broker is ready to use."""
        DELETING: Broker._Status.ValueType  # 3
        """Broker is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Broker.Status.ValueType  # 0
    CREATING: Broker.Status.ValueType  # 1
    """Broker is being created."""
    ACTIVE: Broker.Status.ValueType  # 2
    """Broker is ready to use."""
    DELETING: Broker.Status.ValueType  # 3
    """Broker is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the broker."""
    folder_id: builtins.str
    """ID of the folder that the broker belongs to."""
    name: builtins.str
    """Name of the broker. The name is unique within the folder."""
    description: builtins.str
    """Description of the broker. 0-256 characters long."""
    status: global___Broker.Status.ValueType
    """Status of the broker."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def log_options(self) -> global___LogOptions:
        """Options for logging broker events"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___Broker.Status.ValueType = ...,
        log_options: global___LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "log_options", b"log_options", "name", b"name", "status", b"status"]) -> None: ...

global___Broker = Broker

@typing.final
class BrokerCertificate(google.protobuf.message.Message):
    """A broker certificate."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    CERTIFICATE_DATA_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker that the certificate belongs to."""
    fingerprint: builtins.str
    """SHA256 hash of the certificates."""
    certificate_data: builtins.str
    """Public part of the certificate."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        fingerprint: builtins.str = ...,
        certificate_data: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "certificate_data", b"certificate_data", "created_at", b"created_at", "fingerprint", b"fingerprint"]) -> None: ...

global___BrokerCertificate = BrokerCertificate

@typing.final
class BrokerPassword(google.protobuf.message.Message):
    """A broker password."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROKER_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    broker_id: builtins.str
    """ID of the broker that the password belongs to."""
    id: builtins.str
    """ID of the password."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        broker_id: builtins.str = ...,
        id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["broker_id", b"broker_id", "created_at", b"created_at", "id", b"id"]) -> None: ...

global___BrokerPassword = BrokerPassword

@typing.final
class LogOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    """Is logging from broker disabled."""
    log_group_id: builtins.str
    """Entry should be written to log group resolved by ID."""
    folder_id: builtins.str
    """Entry should be written to default log group for specified folder."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum log entry level.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "disabled", b"disabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___LogOptions = LogOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/clickhouse/v1/cluster_extension.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/clickhouse/v1/cluster_extension.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/clickhouse/v1/cluster_extension.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1dyandex/cloud/validation.proto\"g\n\x10\x43lusterExtension\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12 \n\ncluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\x07version\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"Y\n\x11\x43lusterExtensions\x12\x44\n\nextensions\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.mdb.clickhouse.v1.ClusterExtensionBs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_CLUSTEREXTENSION'].fields_by_name['name']._loaded_options = None
  _globals['_CLUSTEREXTENSION'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_CLUSTEREXTENSION'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CLUSTEREXTENSION'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLUSTEREXTENSION'].fields_by_name['version']._loaded_options = None
  _globals['_CLUSTEREXTENSION'].fields_by_name['version']._serialized_options = b'\350\3071\001'
  _globals['_CLUSTEREXTENSION']._serialized_start=121
  _globals['_CLUSTEREXTENSION']._serialized_end=224
  _globals['_CLUSTEREXTENSIONS']._serialized_start=226
  _globals['_CLUSTEREXTENSIONS']._serialized_end=315
# @@protoc_insertion_point(module_scope)
